{% load static %}

<script
    src="{% static 'aa_mumble_quick_connect/libs/masonry-layout/4.2.2/masonry.pkgd.min.js' %}"
    integrity="sha512-JRlcvSZAXT8+5SQQAvklXGJuxXTouyq8oIMaYERZQasB8SBDHZaUbeASsJWpk0UUrf89DP3/aefPPrlMR1h1yQ=="
    crossorigin="anonymous"
></script>
